☰
Crate pacaptr_macros
Version 0.19.2
All Items
Macros
?
Crate
pacaptr_macros
source
·
[
−
]
Macros
compat_table
Generates the compatibility table as a docstring on the top of given input.
test_dsl
A DSL (Domain-Specific Language) embedded in Rust, in order to simplify the form of smoke tests.