Macro pacaptr_macros::compat_table
source · compat_table!() { /* proc-macro */ }Expand description
Generates the compatibility table as a docstring on the top of given input.
compat_table!() { /* proc-macro */ }Generates the compatibility table as a docstring on the top of given input.